@@ -11,14 +11,17 @@ from testwizard.commands_audio import WaitForPeakAudioCommand
 
 #Web Commands
 from testwizard.commands_web.AcceptAlertCommand import AcceptAlert
-from testwizard.commands_web.AddArgumentCommand import AddArgument
+from testwizard.commands_web.AddArgumentCommand import AddArgumentCommand
+from testwizard.commands_web.AddCapabilityCommand import AddCapabilityCommand
 from testwizard.commands_web.AddChromeExtensionCommand import AddChromeExtension
 from testwizard.commands_web.AuthenticateUrlCommand import AuthenticateUrl
 from testwizard.commands_web.ClearCommand import Clear
 from testwizard.commands_web.ClickCommand import Click
+from testwizard.commands_web.CloseWindowCommand import CloseWindowCommand
 from testwizard.commands_web.DeleteAllCookiesCommand import DeleteAllCookies
 from testwizard.commands_web.DismissAlertCommand import DismissAlert
 from testwizard.commands_web.DragNDropCommand import DragNDrop
+from testwizard.commands_web.ExitFullScreenCommand import ExitFullScreenCommand
 from testwizard.commands_web.GetChildrenCommand import GetChildren
 from testwizard.commands_web.GetCurrentWindowHandleCommand import GetCurrentWindowHandle
 from testwizard.commands_web.GetElementCommand import GetElement
@@ -53,7 +56,15 @@ from testwizard.commands_web.SendKeysCommand import SendKeys
 from testwizard.commands_web.SendKeysAlertCommand import SendKeysAlert
 from testwizard.commands_web.StartWebDriverCommand import StartWebDriver
 from testwizard.commands_web.SubmitCommand import Submit
-from testwizard.commands_web.SwitchToFrameCommand import SwitchToFrame
+from testwizard.commands_web.SwitchToDefaultContentCommand import SwitchToDefaultContentCommand
+from testwizard.commands_web.SwitchToFirstWindowCommand import SwitchToFirstWindowCommand
+from testwizard.commands_web.SwitchToFrameCommand import SwitchToFrameCommand
+from testwizard.commands_web.SwitchToFullScreenCommand import SwitchToFullScreenCommand
+from testwizard.commands_web.SwitchToLastWindowCommand import SwitchToLastWindowCommand
+from testwizard.commands_web.SwitchToNextWindowCommand import SwitchToNextWindowCommand
+from testwizard.commands_web.SwitchToNewWindowCommand import SwitchToNewWindowCommand
+from testwizard.commands_web.SwitchToParentFrameCommand import SwitchToParentFrameCommand
+from testwizard.commands_web.SwitchToPreviousWindowCommand import SwitchToPreviousWindowCommand
 from testwizard.commands_web.SwitchToWindowCommand import SwitchToWindow
 from testwizard.commands_web.WaitForControlCommand import WaitForControl
 
@@ -106,7 +117,11 @@ class Web(TestObjectBase):
     
     def addArgument(self, argument):
         self.throwIfDisposed()
-        return AddArgument(self).execute(argument)
+        return AddArgumentCommand(self).execute(argument)
+    
+    def addCapability(self, key, value):
+        self.throwIfDisposed()
+        return AddCapabilityCommand(self).execute(key, value)
     
     def addChromeExtension(self, filePath):
         self.throwIfDisposed()
@@ -123,6 +138,10 @@ class Web(TestObjectBase):
     def click(self, selector):
         self.throwIfDisposed()
         return Click(self).execute(selector)
+        
+    def closeWindow(self, windowName = None):
+        self.throwIfDisposed()
+        return CloseWindowCommand(self).execute(windowName)
     
     def deleteAllCookies(self):
         self.throwIfDisposed()
@@ -135,6 +154,10 @@ class Web(TestObjectBase):
     def dragNDrop(self, object, target):
         self.throwIfDisposed()
         return DragNDrop(self).execute(object, target) 
+        
+    def exitFullScreen(self):
+        self.throwIfDisposed()
+        return ExitFullScreenCommand(self).execute()
     
     def getChildren(self, selector):
         self.throwIfDisposed()
@@ -244,7 +267,7 @@ class Web(TestObjectBase):
         self.throwIfDisposed()
         return ScreenshotBMP(self).execute(filename)
     
-    def screenshotJPG(self, filename, quality):
+    def screenshotJPG(self, filename, quality = None):
         self.throwIfDisposed()
         return ScreenshotJPGCommand(self).execute(filename, quality)
     
@@ -272,9 +295,41 @@ class Web(TestObjectBase):
         self.throwIfDisposed()
         return Submit(self).execute(selector)
     
+    def switchToDefaultContent(self):
+        self.throwIfDisposed()
+        return SwitchToDefaultContentCommand(self).execute()
+        
+    def switchToFirstWindow(self):
+        self.throwIfDisposed()
+        return SwitchToFirstWindowCommand(self).execute()
+        
     def switchToFrame(self, selector):
         self.throwIfDisposed()
-        return SwitchToFrame(self).execute(selector)
+        return SwitchToFrameCommand(self).execute(selector)
+        
+    def switchToFullScreen(self, selector = None):
+        self.throwIfDisposed()
+        return SwitchToFullScreenCommand(self).execute(selector)
+        
+    def switchToLastWindow(self):
+        self.throwIfDisposed()
+        return SwitchToLastWindowCommand(self).execute()
+        
+    def switchToNextWindow(self):
+        self.throwIfDisposed()
+        return SwitchToNextWindowCommand(self).execute()
+    
+    def switchToNewWindow(self, selector, url = None):
+        self.throwIfDisposed()
+        return SwitchToNewWindowCommand(self).execute(selector, url)
+        
+    def switchToParentFrame(self):
+        self.throwIfDisposed()
+        return SwitchToParentFrameCommand(self).execute()
+        
+    def switchToPreviousWindow(self):
+        self.throwIfDisposed()
+        return SwitchToPreviousWindowCommand(self).execute()
     
     def switchToWindow(self, selector):
         self.throwIfDisposed()
